module Hermes
  class HousingRequestInitializer
    include Hermes::Concerns::CommonFieldsConcern
    include Hermes::Concerns::SopraXmlSender
    RANDOM_LIST_CHAR = '234567890123456789012345678901234567890123456789123abcdefghijkmnpqrstuvwxyzABCDEFGHJKLMNPQRSTUVWXYZ'
    
    field :unique_number, type: String
    field :hashed_pin_code, type: String
    field :pin_code_created_at, type: DateTime
    field :email, type: String
    field :xml_res, type: String
    
    field :done, type: Boolean

    common_indexes *%i[
      unique_number
      hashed_pin_code
      pin_code_created_at
      email
      done
    ]

    
    belongs_to(
      :housing_request,
      class_name: 'Hermes::HousingRequest',
      index: true
    )
    
    def self.get_all_done
      Hermes::HousingRequestInitializer.where({done: true}).each do |hri|
        ap hri.unique_number
      end
    end
    
    def self.get_all
      Hermes::HousingRequestInitializer.all.each do |hri|
        ap hri.unique_number
      end
    end

    def hidden_email
      return nil unless email

      splited = email.split('@')
      char_count = ((splited[0].length) - 2)
      splited[0] = "#{splited[0][0]}#{'*'*char_count}#{splited[0][(char_count + 1)]}"
      splited.join('@')
    end
    
    def hash_string(str)
      Digest::SHA2.new(512).hexdigest(str)
    end
    
    def format_mail_body(pin_code)
      "Bonjour,

      vous recevez ce mail suite à une tentative de récupération de votre demande sur la base de son numéro unique.
      Afin de confirmer cette récupération pour que votre demande soit dupliquée sur notre site Al'In, veuillez saisir la clé de sécurité dans la zone prévue à cet effet.

      Clé de sécurité : #{pin_code}

      Attention, cette clé de sécurité est valable 24 heures. Passé ce délai il sera nécessaire de recommencer votre démarche.
      Si vous n'êtes pas à l'origine de cette demande, veuillez ne pas prendre en considération ce mail.

      Cordialement

      Toute l'équipe d'Al'in

      ps : ceci est un message automatique, il est inutile de répondre à ce mail.
      "
    end
    
    def call_sne
      if Rails.env.test?
        path = [Hermes::Engine.root, %w[spec xml_bouchon], "DEM_" + unique_number + ".xml"].flatten.join('/').to_s
        pn = Pathname.new(path)
        return {err: 'unknown file'} unless pn.exist?
        self.xml_res = File.read(pn)
      else
        so = Hermes::BoClient::FindNudTask.new(housing_request_initializer_id: id)
        self.xml_res = ExecuteSopraTaskJob.perform_now(so.endpoint, so.to_xml, "post", "Hermes::HousingRequestInitializer", id.to_s) || nil
        if !self.xml_res
          return {email: false, err: "SNE request failed"}
        end
      end
      
      parsed_xml = Hash.from_xml(xml_res.gsub("\n", ""))
      user_mail = parsed_xml["interfaceNuu"]["demande"]["demandeLogement"]["personnePhysique"]["demandeur"]["mel"]
      
      {email: user_mail, err: nil}
    end
    
    def send_pin_code_on_mail
      sne_response = call_sne
      return false if sne_response[:err]
      return :email_empty unless sne_response[:email]

      self.set(email: sne_response[:email])

      random_list_array = RANDOM_LIST_CHAR.split(//)
      pin_code = ''

      6.times do |i|
        pin_code += random_list_array[(SecureRandom.random_number * random_list_array.length).floor]
      end

      self.hashed_pin_code = hash_string(pin_code)
      self.pin_code_created_at = DateTime.current
      mail = Agent.bulk_mail(
        sne_response[:email],
        'securite@masolutionlogement.fr',
        'Récupération demande SNE',
        format_mail_body(pin_code)
      )
      return false unless mail.deliver_later

      save
      pin_code
    end
    
    def check_pin_code(user_input)
      return false unless hashed_pin_code && pin_code_created_at
      
      hash_string(user_input) == hashed_pin_code && (Time.current - pin_code_created_at) < 24.hours
    end
    
    def cant_create_new
      self.done && housing_request && housing_request.request_status != "ANNULEE"
    end 
  
    def hydrate_housing_request_from_sne(user_id)
      parsed_xml = Hash.from_xml(xml_res.gsub("\n", ""))
      
      main_applicant = Hermes::Applicant.find_or_create_by(user_id: user_id, main_user_id: user_id)
      housing_request = Hermes::HousingRequest.create(user_id: user_id, main_user_id: user_id, main_applicant: main_applicant.id)
      data = {unique_number: unique_number, housing_request_id: housing_request.id, creation_date: parsed_xml["interfaceNuu"]["demande"]["demandeLogement"]["dateCreationDemande"]}
      
      if nud = Hermes::Nud.create(data)
        housing_request.nud_ids = [nud.id]
      end
      housing_request.assign_attributes(housing_request_reversed_map(parsed_xml))
      housing_request.is_active =  true
      housing_request.form_status="invalid"
      main_applicant.assign_attributes(applicant_reversed_map(parsed_xml, true, nil))
      if main_applicant.save
        housing_request.owned_housing_details = main_applicant.owned_housing_details
        housing_request.actual_housing_details = main_applicant.actual_housing_details
      end
      xml_coapps = parsed_xml["interfaceNuu"]["demande"]["demandeLogement"]["personnePhysique"]["listeCotitulaire"]
      if xml_coapps
        xml_coapps = xml_coapps.is_a?(Array) ? xml_coapps : [xml_coapps]
        coapplicants = []
        xml_coapps.each_with_index do |xml_coapp, i|
          coapp_params = applicant_reversed_map(parsed_xml, false, i).merge(user_id: user_id)
          if coapplicant = Hermes::Applicant.create(coapp_params)
            coapplicants << { "rel_type": xml_coapp["cotitulaire"]["lienDemandeur"]["code"],  "id": coapplicant.id }
          end
        end
        housing_request.coapplicants = coapplicants
      end 
      
      if housing_request.save
        self.housing_request_id = housing_request.id.to_s
        self.done = true
        save
        if Rails.env != 'test'
          so = Hermes::BoClient::AddRequestTask.new(housing_request_id: housing_request.id.to_s, nud_id: nud.id.to_s)
          xml = so.to_xml
          housing_request.set(viewed_by_colaborator_offre_logement: false, last_xml_flux_30: xml, updated_at: DateTime.current)
          so.execute
        end

        return housing_request
      else
        return nil
      end
    end
      
    def applicant_map
    
    end
    
    def housing_request_reversed_map(xml)
      demande_logement = xml["interfaceNuu"]["demande"]["demandeLogement"] #["personnePhysique"]["demandeur"]["mel"]
      personnePhysique = demande_logement["personnePhysique"]
      demandeur = personnePhysique["demandeur"]
      attributes = {
        ec_law_ressources: demande_logement["ressourcesLoiEC"],
        lessor_siren: personnePhysique["logementActuel"]&.fetch("compSIRENOrgBailleur", nil),
        electronical_renewal: demande_logement["renouvellementElec"],
        widen_request: demande_logement["logementRecherche"]["demandeElargie"],
        lessor_name: personnePhysique['logementActuel']['compNomOrgBailleur'],
        work_contract_type: [
          demandeur["situationProfessionnelle"]["typeContratTravail"]&.fetch("code", nil)
        ],
        dalo: xml["interfaceNuu"]["demande"]&.fetch("informationDalo", nil)&.fetch("statutDalo", nil)&.fetch("code", nil) == "ACTIF" ? true : false,
        with_car_park: demande_logement["logementRecherche"]["avecParking"],
        mutation: !!demande_logement['renouvellement'],
        seeking_first_floor: demande_logement["logementRecherche"]["rezDeChaussee"],
        seeking_elevator: demande_logement["logementRecherche"]["sansAscenseur"],
        seeked_max_rent: demande_logement["logementRecherche"]["montantLoyer"].to_i,
        precisions: demande_logement["precision"],
        seeked_housing_categories: [
          demande_logement["logementRecherche"]["categorieLogementRecherche"]&.fetch("code", nil)
        ],
        is_house_owner: personnePhysique["logementActuel"]["proprietaire"],
        
        requester_firstname: demandeur["prenom"],
        requester_lastname: demandeur["nom"],
        
        requester_email: demandeur["mel"],
       # created_at: demande_logement["dateCreationDemande"],
        sne_created_at: demande_logement["dateCreationDemande"],
        radiation_date: demande_logement["radiation"]&.fetch("dateRadiation", nil),
        radiation_motive: demande_logement["radiation"]&.fetch("motifRadiation", nil)&.fetch("code", nil),
        
      }
      attributes[:forcing_duplicate] = (demande_logement["forcerDoublon"] != "false") if demande_logement["forcerDoublon"]
      
      logementActuel = personnePhysique["logementActuel"] || {}
      if logementActuel
        modeleLogement = logementActuel["listeModeleLogement"]&.fetch("modeleLogement", nil)
        attributes[:housing_type_list] = modeleLogement.is_a?(Array) ? [] : [modeleLogement&.fetch("code", nil)]
        if modeleLogement.is_a?(Array)
          attributes[:housing_type_list] = []
          modeleLogement.each_with_index do |val|
            attributes[:housing_type_list].push (val&.fetch("code", nil))
          end
        end
      end
      if personnePhysique["personneANaitre"]
        attributes[:unborn_children] = [{"anticipated_birth" => personnePhysique["personneANaitre"]["dateNaissancePrevue"], "nb_child_birth" => personnePhysique["personneANaitre"]["nombre"]}]
      end
      
      if (demande_logement["principauxMotifDemande"]["motifDemande"].is_a? Hash)
        attributes[:motivation1] = demande_logement["principauxMotifDemande"]["motifDemande"]&.fetch("code", nil)
      else
        attributes[:motivation1] = demande_logement["principauxMotifDemande"]["motifDemande"]&.fetch(0, {})&.fetch("code", nil)
        attributes[:motivation2] = demande_logement["principauxMotifDemande"]["motifDemande"]&.fetch(1, {})&.fetch("code", nil)
        attributes[:motivation3] = demande_logement["principauxMotifDemande"]["motifDemande"]&.fetch(2, {})&.fetch("code", nil)
      end
      attributes[:seeked_types] = []
      typeLogement = demande_logement["logementRecherche"]["listeTypeLogement"]["typeLogement"]
      typeLogement = typeLogement.is_a?(Array) ? typeLogement : [typeLogement]
      typeLogement&.each do |type|
        attributes[:seeked_types].push(type&.fetch("code", nil).to_s)
      end
      
      attributes[:dependents] = []
      demandeur["listeRessourceRecuePersACharge"] = demandeur["listeRessourceRecuePersACharge"].is_a?(Array) ? demandeur["listeRessourceRecuePersACharge"] : [demandeur["listeRessourceRecuePersACharge"]]
      demandeur["listeRessourceRecuePersACharge"]&.each_with_index do |persACharge, i|
        
        if persACharge && persACharge["detailRessource"]
          attributes[:dependents][i] ||= {}
          attributes[:dependents][i]["monthly_incomes"] ||= {}
          ressources = persACharge["detailRessource"].is_a?(Array) ? persACharge["detailRessource"] : [persACharge["detailRessource"]]
          ressources.each do |ressource|
            attributes[:dependents][i]["monthly_incomes"][ressource&.fetch("code", nil).to_s] = ressource["montant"].to_i
          end
        
        end
      end
      
      demandeur["listeRessourceVerseePersACharge"] = demandeur["listeRessourceVerseePersACharge"].is_a?(Array) ? demandeur["listeRessourceVerseePersACharge"] : [demandeur["listeRessourceVerseePersACharge"]]
      demandeur["listeRessourceVerseePersACharge"]&.each_with_index do |persACharge, i|
        if persACharge && persACharge["detailRessource"]
          attributes[:dependents][i] ||= {}
          attributes[:dependents][i]["monthly_charges"] ||= {}
          attributes[:dependents][i]["monthly_charges"][persACharge["detailRessource"]["ressource"]&.fetch("code", nil).to_s] = persACharge["detailRessource"]["montant"].to_i
        end
      end
      if personnePhysique["listePersonneACharge"] && personnePhysique["listePersonneACharge"]["personneACharge"]
        personnePhysique["listePersonneACharge"]["personneACharge"] = personnePhysique["listePersonneACharge"]["personneACharge"].is_a?(Array) ? personnePhysique["listePersonneACharge"]["personneACharge"] : [personnePhysique["listePersonneACharge"]["personneACharge"]]
        
        personnePhysique["listePersonneACharge"]["personneACharge"]&.each_with_index do |persACharge, i|
          if persACharge
            
            attributes[:dependents][i] ||= {}
            attributes[:dependents][i]["last_name"] = persACharge["nom"]
            attributes[:dependents][i]["first_name"] = persACharge["prenom"]
            attributes[:dependents][i]["birth_date"] = persACharge["dateNaissance"]
            attributes[:dependents][i]["rel_type"] = persACharge["lienParente"]&.fetch("code", nil)
            attributes[:dependents][i]["sex"] = persACharge["sexe"]&.fetch("code", nil)
          
          end
        end
      end
      dependents_index = attributes[:dependents].length 
      if (personnePhysique["listePersonneEnGarde"])
        personnePhysique["listePersonneEnGarde"]["personneEnGarde"] = personnePhysique["listePersonneEnGarde"]["personneEnGarde"].is_a?(Array) ? personnePhysique["listePersonneEnGarde"]["personneEnGarde"] : [personnePhysique["listePersonneEnGarde"]["personneEnGarde"]]
        personnePhysique["listePersonneEnGarde"]["personneEnGarde"]&.each_with_index do |persACharge, i|
          if persACharge
            attributes[:dependents][i + dependents_index] ||= {}
            attributes[:dependents][i + dependents_index]["last_name"] ||= persACharge["nom"]
            attributes[:dependents][i + dependents_index]["first_name"] ||= persACharge["prenom"]
            attributes[:dependents][i + dependents_index]["birth_date"] ||= persACharge["dateNaissance"]
            attributes[:dependents][i + dependents_index]["coparentality"] = persACharge&.fetch("coParentalite")&.fetch("code", nil)
            attributes[:dependents][i + dependents_index]["sex"] ||= persACharge["sexe"]&.fetch("code", nil)
          end
        end
        
      end
      
      
      attributes[:postal_details] = {}
      adressePostale = demandeur["adressePostale"] || {}
      attributes[:postal_details]['etranger'] = adressePostale["etranger"]
      attributes[:postal_details]['appartment_number'] = adressePostale["appartement"]
      attributes[:postal_details]['appartment_floor'] = adressePostale["etage"]
      attributes[:postal_details]['appartment_staircase'] = adressePostale["escalier"]
      attributes[:postal_details]['appartment_building'] = adressePostale["batiment"]
      attributes[:postal_details]['address_add_address'] = adressePostale["compAdresse"]
      attributes[:postal_details]['address_number'] = adressePostale["numero"]
      attributes[:postal_details]['address_street'] = adressePostale["voie"]
      attributes[:postal_details]['appartment_address_place'] = adressePostale["lieuDit"]
      attributes[:postal_details]['postal_code'] = adressePostale["codePostal"]
      attributes[:postal_details]['current_address_postal_code'] = adressePostale["codePostalEtranger"]
      attributes[:postal_details]['foreign_city'] = adressePostale["communeEtranger"]
      attributes[:postal_details]['foreign_country'] = adressePostale["pays"]
      attributes[:postal_details]['houser_name'] = adressePostale["nomHebergeant"]
      attributes[:postal_details]['address_insee_code'] = adressePostale["commune"]&.fetch("code", nil)
      
      attributes[:seeked_localisation_list] = []
      localisationSouhaite = demande_logement["logementRecherche"]["listeLocalisationSouhaite"]["localisationSouhaite"]
      localisationSouhaite = localisationSouhaite.is_a?(Array) ? localisationSouhaite : [localisationSouhaite]
      localisationSouhaite.each_with_index do |loc, i|
        if (loc)
          res = {}
          res["code"] = loc["commune"]["code"]
          res["codesPostaux"] = [loc["codePostal"]]
          res["seeked_epci_first_quartil"] = loc["seuilEPCIPremierQuartile"]
          res["seeked_quartil_belongings"] = loc["quartileAppartenance"]
          attributes[:seeked_localisation_list].push res
        end
      end
      
      if demande_logement["listeHandicap"]
        if demande_logement["listeHandicap"].is_a?(Hash)
          demande_logement["listeHandicap"] = demande_logement["listeHandicap"]["handicap"].is_a?(Array) ? demande_logement["listeHandicap"]["handicap"] : [demande_logement["listeHandicap"]["handicap"]]
        end
        attributes[:disability_details] = [{}]
        demande_logement["listeHandicap"].each_with_index do |handicap, i|
          
          handicap = handicap
          
          attributes[:disability_details][i] ||= {}
          attributes[:disability_details][i] = {"disability_states": handicap["etatHandicap"]&.fetch("code", nil),
                                                "walking_capacities": handicap["capaciteMarcheHandicap"]&.fetch("code", nil),
          
          
                                                "birth_date": handicap["dateNaissance"],
                                                "accompanied": handicap["accompagne"] == "true",
                                                "physical_disability": handicap["handicapMoteur"] == "true",
                                                "sensory_disability": handicap["handicapSensoriel"] == "true",
                                                "other_disability": handicap["handicapAutre"] == "true",
                                                "special_need": handicap["compAutreNature"],
                                                "other_need": handicap["besoinAutre"],
          }
          if handicap["referent"]
            attributes[:disability_details][i]["disability_referent"] = {
              "recognized_disability": (handicap["referent"]["handicapReconnu"] == "true"),
              "near_home": (handicap["referent"]["procheDomicile"] == "true"),
              "name": handicap["referent"]["nom"],
              "address": handicap["referent"]["adresse"],
              "phone": handicap["referent"]["tel"],
              "email": handicap["referent"]["mel"],
            }
          end
          if handicap["listeNatureHandicapSensoriel"]
            attributes[:disability_details][i]["sensory_disability_kinds"] = extract_codes(handicap, 'listeNatureHandicapSensoriel')
          end
          if handicap["listeNatureHandicapMoteur"]
            attributes[:disability_details][i]["physical_disability_kinds"] = extract_codes(handicap, 'listeNatureHandicapMoteur')
          end
          if handicap["listeAideTechniqueHandicap"]
            attributes[:disability_details][i]["disability_technical_helps"] = extract_codes(handicap, 'listeAideTechniqueHandicap')
          end
          if handicap["listeEquipementHandicap"]
            attributes[:disability_details][i]["disability_equipments"] = extract_codes(handicap, 'listeEquipementHandicap')
          end
        end
      end
      attributes
    end

    def extract_codes(handicap, attribute_name)
      return [] unless handicap[attribute_name]

      extrated_array = if handicap[attribute_name].is_a?(Array)
        if handicap[attribute_name][0] && handicap[attribute_name][0].is_a?
          handicap[attribute_name][0]
        else
          handicap[attribute_name]
        end
      elsif handicap[attribute_name].is_a?(Hash)
        [handicap[attribute_name]]
      end

      extrated_array.map{|o| o.fetch("code", nil)}
    end 
    
    def applicant_reversed_map(xml, is_main_applicant, coaplicantIndex)
      demande_logement = xml["interfaceNuu"]["demande"]["demandeLogement"] #["personnePhysique"]["demandeur"]["mel"]
      personnePhysique = demande_logement["personnePhysique"]
      if is_main_applicant
        demandeur = personnePhysique["demandeur"]
      else
        demandeur = (personnePhysique["listeCotitulaire"].is_a? Array) ? personnePhysique["listeCotitulaire"][coaplicantIndex]["cotitulaire"] : personnePhysique["listeCotitulaire"]["cotitulaire"]
      end
      attributes = {
        nationality: demandeur["nationalite"]&.fetch("code", nil),
        civility: demandeur["civilite"]&.fetch("code", nil),
        birth_date: demandeur["dateNaissance"],
        homephone: demandeur["telDomicile"],
        workphone: demandeur["telTravail"],
        cellphone: demandeur["telPortable"],
        has_other_employers: demandeur["situationProfessionnelle"]&.fetch("multiEmployeur", nil),
        year_minus_one: demandeur["revenuFiscal"]&.fetch("anneeMoins1", nil),
        amount_year_minus_one: demandeur["revenuFiscal"]&.fetch("montantMoins1", nil).to_i,
        year_minus_two: demandeur["revenuFiscal"]&.fetch("anneeMoins2", nil),
        amount_year_minus_two: demandeur["revenuFiscal"]&.fetch("montantMoins2", nil).to_i,
        family_situation: demandeur["situationFamiliale"]&.fetch("code", nil),
        email_advances_assistant: demandeur['melAssistantDemarches']
      }
      if is_main_applicant
        attributes[:actual_housing_details] = {}
        
        adresseLogement = personnePhysique["adresseLogement"] || {}
        logementActuel = personnePhysique["logementActuel"] || {}
        attributes[:actual_housing_details]['etranger'] = adresseLogement["etranger"]
        attributes[:actual_housing_details]['appartment_number'] = adresseLogement["appartement"]
        attributes[:actual_housing_details]['appartment_floor'] = adresseLogement["etage"]
        attributes[:actual_housing_details]['appartment_staircase'] = adresseLogement["escalier"]
        attributes[:actual_housing_details]['appartment_building'] = adresseLogement["batiment"]
        attributes[:actual_housing_details]['address_add_address'] = adresseLogement["compAdresse"]
        attributes[:actual_housing_details]['appartment_address_place'] = adresseLogement["lieuDit"]
        attributes[:actual_housing_details]['address_number'] = adresseLogement["numero"]
        attributes[:actual_housing_details]['way'] = adresseLogement["voie"]
        attributes[:actual_housing_details]['postal_code'] = adresseLogement["codePostal"]
        attributes[:actual_housing_details]['address_insee_code'] = adresseLogement["commune"]&.fetch("code", nil)
        attributes[:actual_housing_details]['houser_name'] = adresseLogement["nomHebergeant"]
        attributes[:actual_housing_details]['current_address_postal_code'] = adresseLogement["codePostalEtranger"]
        attributes[:actual_housing_details]['foreign_city'] = adresseLogement["communeEtranger"]
        attributes[:actual_housing_details]['foreign_country'] = adresseLogement["pays"]
        attributes[:actual_housing_details]['monthly_rental_amount'] = logementActuel["montantMensuelLoyer"].to_s
        attributes[:actual_housing_details]['APL_monthly_amount'] = logementActuel["montantMensuelAPL"].to_s
        attributes[:actual_housing_details]['type'] = logementActuel["typeLogementActuel"]&.fetch("code", nil)
        attributes[:actual_housing_details]['number_of_resident'] = logementActuel["nombreHabitant"]
        attributes[:actual_housing_details]['area'] = logementActuel["surface"]
        attributes[:actual_housing_details]['housing_category_list'] = logementActuel["categorieLogement"]&.fetch("code", nil)
        attributes[:actual_housing_details]['number_of_resident'] = logementActuel["nombreHabitant"]
        attributes[:actual_housing_details]['housing_surface'] = logementActuel["surface"]
        attributes[:actual_housing_details]['is_house_owner'] = logementActuel["proprietaire"]
        attributes[:actual_housing_details]['housing_category_list'] = logementActuel["categorieLogement"]&.fetch("code", nil)
        attributes[:actual_housing_details]['typeLogementActuel'] = logementActuel["typeLogementActuel"]&.fetch("code", nil)
        if logementActuel["proprietaire"]
          attributes[:owned_housing_details] = attributes[:actual_housing_details]
          attributes[:owned_housing_details]['type']  = logementActuel["typeLogementPossede"]&.fetch("code", nil) if logementActuel["typeLogementPossede"]&.fetch("code", nil)
        end
       
      else
        attributes[:temporary_id] = demandeur['identifiantTemporaire']
      end
      attributes[:ss_id] = demandeur["nir"]
      attributes[:first_name] = demandeur['prenom']
      attributes[:last_name] = demandeur["nom"]
      attributes[:patronymic_name] = demandeur["nomPatronymique"]
      attributes[:email] = demandeur["mel"]
      attributes[:sms_notification] = (demandeur["notifSms"] != "false") if demandeur["notifSms"]
      attributes[:event_notification] = (demandeur["notifEvt"] != "false") if demandeur["notifEvt"]
      attributes[:work_contract_type] = demandeur["situationProfessionnelle"]&.fetch("typeContratTravail")&.fetch("code", nil)
      attributes[:monthly_incomes] = {}
      demandeur['listeRessourceRecue'] = demandeur['listeRessourceRecue'].is_a?(Array) ? demandeur['listeRessourceRecue'] : [demandeur['listeRessourceRecue']]
      demandeur['listeRessourceRecue']&.each do |ressource|
        
        if ressource
          detailRessource = ressource["detailRessource"].is_a?(Array) ? ressource["detailRessource"] : [ressource["detailRessource"]]
          detailRessource.each do |detail|
            attributes[:monthly_incomes][detail["ressource"]&.fetch("code", nil).to_s] = detail["montant"].to_i
          end
        end
      end
      attributes[:monthly_charges] = {}
      demandeur['listeRessourceVersee'] = demandeur['listeRessourceVersee'].is_a?(Array) ? demandeur['listeRessourceVersee'] : [demandeur['listeRessourceVersee']]
      demandeur['listeRessourceVersee']&.each do |ressource|
        if ressource
          detailRessource = ressource["detailRessource"].is_a?(Array) ? ressource["detailRessource"] : [ressource["detailRessource"]]
          detailRessource.each do |detail|
            attributes[:monthly_charges][detail["ressource"]&.fetch("code", nil).to_s] = detail["montant"].to_i
          end
        end
      end
      
      attributes[:profession_details] = {}
      if demandeur['situationProfessionnelle']['etranger']
        if (demandeur['situationProfessionnelle']['etranger'] == "false")
          attributes[:profession_details]["foreign"] = false
        else
          attributes[:profession_details]["foreign"] = true
        end
      end
      attributes[:profession_details]["profession"] = demandeur['situationProfessionnelle']['profession']
      attributes["workplace_postal_code"] = demandeur['situationProfessionnelle']['codePostal']
      attributes[:foreign_workplace_postal_code] = demandeur['situationProfessionnelle']['codePostalEtranger']
      attributes[:foreign_workplace_locality] = demandeur['situationProfessionnelle']['communeEtranger']
      attributes[:foreign_workplace_country] = demandeur['situationProfessionnelle']['pays']
      attributes[:workplace_insee_code] = demandeur['situationProfessionnelle']['commune']&.fetch("code", nil).to_s
      attributes[:main_employer_name] = demandeur['situationProfessionnelle']['nomEmployeurPrincipal']
      attributes[:main_employer_siret] = demandeur['situationProfessionnelle']['siretEmployeur']
      return attributes
    end
  end
end
